Usage
checkfit(gg.fit, x, groups, type='data', logexpr=FALSE, xlab, ylab, main, lty, lwd, ...)
Arguments
gg.fit
GaGa or MiGaGa fit (object of type gagafit, as
returned by fitGG).
x
ExpressionSet, exprSet, data frame or matrix
containing the gene expression measurements used to fit the model.
groups
If x is of type ExpressionSet or
exprSet, groups should be the name of the column
in pData(x) with the groups that one wishes to compare. If
x is a matrix or a data frame, groups should be a
vector indicating to which group each column in x
corresponds to.
type
data checks marginal density of the data;
shape checks shape parameter; mean checks mean
parameter; shapemean checks the joint of shape and mean
parameters
logexpr
If set to TRUE, the expression values are in log2 scale.
...
Other arguments to be passed to plot